@@ -8,6 +8,7 @@ use Exporter qw(
     import
 );
 our @EXPORT_OK  = qw(
+    clear_coll_data
     get_redis
     verify_redis
 );
@@ -20,6 +21,7 @@ use Try::Tiny;
 use Redis::CappedCollection qw(
     $DEFAULT_SERVER
     $DEFAULT_PORT
+    $NAMESPACE
 );
 
 sub get_redis
@@ -40,7 +42,6 @@ sub get_redis
         last unless $error;
         sleep 1;
     }
-    return if $error;
 
     return wantarray ? ( $redis, $error ) : $redis;
 }
@@ -52,7 +53,13 @@ sub verify_redis
     my $skip_msg;
     my $port = Net::EmptyPort::empty_port( $DEFAULT_PORT );
 
-    $redis = get_redis( conf => { port => $port }, timeout => 3 );
+    $redis = get_redis(
+        conf    => {
+            port                => $port,
+            'maxmemory-policy'  => 'noeviction',
+        },
+        timeout => 3,
+    );
     if ( $redis )
     {
         eval { $real_redis = Redis->new( server => $DEFAULT_SERVER.":".$port ) };
@@ -68,4 +75,14 @@ sub verify_redis
     return $redis, $skip_msg, $port;
 }
 
+sub clear_coll_data {
+    my ( $coll ) = @_;
+
+    eval { $coll->_call_redis( 'DEL', $NAMESPACE.':Q:'.$coll->name ); };
+    eval { $coll->_call_redis( 'DEL', $NAMESPACE.':S:'.$coll->name ); };
+    eval { $coll->_call_redis( 'DEL', $coll->_call_redis( 'KEYS', $NAMESPACE.':I:'.$coll->name.":*" ) ); };
+    eval { $coll->_call_redis( 'DEL', $coll->_call_redis( 'KEYS', $NAMESPACE.':D:'.$coll->name.":*" ) ); };
+    eval { $coll->_call_redis( 'DEL', $coll->_call_redis( 'KEYS', $NAMESPACE.':T:'.$coll->name.":*" ) ); };
+}
+
 1;
